summaryrefslogtreecommitdiff
path: root/gst/gstpreset.c
diff options
context:
space:
mode:
authorDavid Schleef <ds@schleef.org>2008-06-11 20:07:31 +0000
committerJan Schmidt <thaytan@mad.scientist.com>2008-06-11 20:07:31 +0000
commiteaeb1a3434247341e396a3dd553e3f296b310299 (patch)
treebb5ee7076983203ceabcac44ee12119c0f133326 /gst/gstpreset.c
parent9e6cce35a06ea3eab85f0d35da0d82eabb238ce7 (diff)
Rename DATADIR to GST_DATADIR to avoid build problems
Original commit message from CVS: * configure.ac: * gst/gstpreset.c: Rename DATADIR to GST_DATADIR to avoid build problems on win32. Patch By: David Schleef <ds@schleef.org> Fixes: #536857
Diffstat (limited to 'gst/gstpreset.c')
-rw-r--r--gst/gstpreset.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gst/gstpreset.c b/gst/gstpreset.c
index b32aa3fda..775535ea6 100644
--- a/gst/gstpreset.c
+++ b/gst/gstpreset.c
@@ -149,8 +149,8 @@ preset_get_paths (GstPreset * preset, const gchar ** preset_user_path,
if (!(preset_path = g_type_get_qdata (type, preset_system_path_quark))) {
gchar *preset_dir;
- /* system presets in '$DATADIR/gstreamer-0.10/presets/GstAudioPanorama.prs' */
- preset_dir = g_build_filename (DATADIR, "gstreamer-" GST_MAJORMINOR,
+ /* system presets in '$GST_DATADIR/gstreamer-0.10/presets/GstAudioPanorama.prs' */
+ preset_dir = g_build_filename (GST_DATADIR, "gstreamer-" GST_MAJORMINOR,
"presets", NULL);
GST_INFO_OBJECT (preset, "system_preset_dir: '%s'", preset_dir);
preset_path = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s.prs",